@@ -55,6 +55,7 @@ class DRKApp:
             "dropdowns": "case/dropdown/",
             "case_list": "case/all-case/",
             "third-party": "case/third-party-case-details/",
+            "threat-data": "case/threat-data/",
         }
 
     def check_required_params(self):
@@ -178,3 +179,32 @@ class DRKApp:
         else:
             raise Exception(
                 f"Failed to fetch data from API with status code {response.status_code} and message {response.text}")
+
+    def get_threat_data(self, threat=None):
+        if threat is None:
+            raise ValueError("Threat is required")
+
+        api = self.api
+        self.check_required_params()
+
+        api_url = self.get_api_url()
+
+        final_api = self.all_api_list().get(api, None)
+
+        headers = {
+            "Authorization": f"Bearer {self.token}",
+            "Content-Type": "application/json",
+            "origin": api_url
+        }
+
+        response = requests.get(
+            f"{api_url}{final_api}{threat}/?api-key={self.token}",
+            headers=headers
+        )
+
+        if response.status_code == 200 or response.status_code == 201:
+            data = response.json()
+            return {"data": data, "status": response.status_code}
+        else:
+            raise Exception(
+                f"Failed to fetch data from API with status code {response.status_code} and message {response.text}")
